"""
This module contains unit tests for the SingleStatementParser and DeclarationsTreeVisitor.
It verifies that the parser correctly interprets and parses single statement types,
and the visitor accurately transforms the parsed AST into the expected string representation.
"""
from uppaal2jetracer.parser.declarationparser.declaration_parser import SingleStatementParser
from uppaal2jetracer.declarations.declarations_tree_visitor import DeclarationsTreeVisitor

ss_parser = SingleStatementParser(lex_optimize = False, yacc_optimize = False, yacc_debug = False)
tree_visitor = DeclarationsTreeVisitor()

def test_bool_true_assignment():
    statement = "x = true"
    declaration_ast = ss_parser.parse(statement, "", False)
    assert ("(FileAST: "
            "(Assignment: (ID: x) = ((Constant: true)))"
            ")") == tree_visitor.visit_fileast(declaration_ast)

def test_bool_false_assignment():
    statement = "x = false"
    declaration_ast = ss_parser.parse(statement, "", False)
    assert ("(FileAST: "
            "(Assignment: (ID: x) = ((Constant: false)))"
            ")") == tree_visitor.visit_fileast(declaration_ast)

def test_x_eq_y_plus_3():
    statement = "x = y + 3"
    declaration_ast = ss_parser.parse(statement, "", False)
    assert ("(FileAST: "
            "(Assignment: (ID: x) = ((BinaryOp: ((ID: y)) + ((Constant: 3)))))"
            ")") == tree_visitor.visit_fileast(declaration_ast)

def test_x_geq_y():
    statement = "x >= y"
    declaration_ast = ss_parser.parse(statement, "", False)
    assert ("(FileAST: "
            "(BinaryOp: ((ID: x)) >= ((ID: y)))"
            ")") == tree_visitor.visit_fileast(declaration_ast)

def test_3_eq_5():
    statement = "3 == 5"
    declaration_ast = ss_parser.parse(statement, "", False)
    assert ("(FileAST: "
            "(BinaryOp: ((Constant: 3)) == ((Constant: 5)))"
            ")") == tree_visitor.visit_fileast(declaration_ast)

def test_x_eq_funccall():
    statement = "x = add(5, 6)"
    declaration_ast = ss_parser.parse(statement, "", False)
    assert ("(FileAST: "
            "(Assignment: (ID: x) = ((FuncCall: (ID: add)"
            "((ExprList: (Constant: 5), (Constant: 6))))))"
            ")") == tree_visitor.visit_fileast(declaration_ast)
