/**
 * This file holds the event for running a certain version.
 * 
 * @module scripts/events/main/select_version
 */

import RequestHandler from "../../request_handler.js";
import PageHandler from "../../page_handler.js";
import EventHandler from "../../event_handler.js";

/**
 * Selects a certain version to be run.
 * 
 * @function select_version_event
 * 
 * @param {HTMLElement} target            - Is the targeted UI element that was clicked.
 * @param {object} args                   - The data attributes of the targeted element.
 * @param {RequestHandler} requestHandler - The handler for HTTP requests.
 * @param {PageHandler} pageHandler       - The handler for UI updates.
 * @param {EventHandler} eventHandler     - The handler for the events.
 */
function select_version_event(target, args, requestHandler, pageHandler, eventHandler) {

    let versionId = pageHandler.getVersionId(target);

    requestHandler.POST("/api/run", [ versionId ], {}, (res) => {

        if (res.type) {

            pageHandler.addError(res.message, false);
            pageHandler.closeVersionsFrame();

        } else {

            pageHandler.addError(res.error);

        }

        eventHandler.isHandlingEvent = false;

    });

}

export default select_version_event;
