"""Config

This file provides all configuration settings required by the server database.

This file can be imported as a module and contains the following classes:

    * Config: Class for holding the configuration variables.
"""

import os

basedir = os.path.abspath(os.path.dirname(__file__))


class Config:
    """
    A class for holding configuration variables for the server database.
    """

    SQLALCHEMY_DATABASE_URI = (os.environ.get("DATABASE_URL") or "sqlite:///" +
                               os.path.join(basedir, "app.db"))
    SECRET_KEY = os.environ.get("SECRET_KEY") or "ea5a3c00-0ce0-47eb-870c-307db1b9ccf3"

    GLOBAL_ID = os.environ.get("GLOBAL_ID") or 1
    SECRET_TOKEN = os.environ.get("SECRET_TOKEN") or "u2j"

    VALID_FILE_NAME_FORMAT = "^[A-Za-z0-9_-]*$"
    VALID_FILE_EXTENSIONS = os.environ.get("VALID_FILE_EXTENSIONS") or [".xml"]
    RELATIVE_FILE_PATH = os.environ.get("RELATIVE_FILE_PATH") or "assets" + os.sep + "parsed"

    DEBUG_MODE = os.environ.get("DEBUG_MODE") or False

    SOCKET_TIMOUT_DURATION = os.environ.get("") or 60
    SOCKET_INTERVAL_DURATION = os.environ.get("") or 25

    RUNNING_THREAD = None
